--[[
	LootDestroyer

	By sarf

	This mod allows loot to be automatically destroyed.
	Looting (and destroying) by both left- and right-clicking is allowed.
	The loot that should be destroyed must be specified by the user
	(by shift-rightclicking it in the LootFrame).
	
	It destroys the item by picking up the last item it encounters in 
	your inventory that matches the unwanted item name.
	
	Thanks go to Mugendai for his code, which remains an inspiration for me.
	Thanks also goes to Bayta (on the official WoW community boards), who came up with the idea, 
	as well as karconn (Bayta's nick on the CosmosUI.org forums) for providing much valued feedback.
	
	Credits for the ultra-nice unwanted item texture goes to myself. I suck at drawing things, by the way, 
	so if you want your name here, send me your creation and I'll probably use it instead.
	
	CosmosUI URL:
	http://www.cosmosui.org/forums/viewtopic.php?t=257
	
	Bayta's Thread URL:
	http://www.worldofwarcraft.com/thread.aspx?fn=wow-interface-customization&t=7202
   ]]
   

-- Constants
LOOTDESTROYER_MAX_NUMBER_OF_BAGS = 4; -- add one because it starts at zero

LOOTDESTROYER_UNWANTED_ITEM_TEXTURE = "Interface\\AddOns\\LootDestroyer\\Skin\\Icons\\UnwantedItem-Icon";
LOOTDESTROYER_UNWANTED_ITEM_TEXTURE_WOW = "Interface\\Icons\\Spell_Shadow_SacrificalShield";


-- Variables
LootDestroyer_RecentUnwantedItems = {};
LootDestroyer_Saved_LootFrameItem_OnClick = nil;
LootDestroyer_Saved_ContainerFrameItemButton_OnClick = nil;
LootDestroyer_Saved_LootFrame_Update = nil;
LootDestroyer_UnwantedItems = {};

LootDestroyer_CosmosRegistered = 0;
LootDestroyer_DebugPrint_Enabled = false;

-- Variables that the user is supposed to be able to affect
LootDestroyer_Enabled = 0;

-- Create toggles for these
LootDestroyer_OverloadLootUpdate_Enabled = 1;				-- if the LootFrame_Update() should be overloaded at all, needed to change the look of the icons
LootDestroyer_Display_Unwanted_Use_Quantity_Enabled = 1;	-- less easy to see, less CPU used
LootDestroyer_Display_Unwanted_Use_Texture_Enabled = 1;		-- easier to see, might cause some CPU problems, might cause interference problems



function LootDestroyer_OnLoad()
	LootDestroyer_Register();
end

function LootDestroyer_Register_Cosmos()
	if ( ( Cosmos_RegisterConfiguration ) and ( LootDestroyer_CosmosRegistered == 0 ) ) then
		Cosmos_RegisterConfiguration(
			"COS_LOOTDESTROYER_HEADER",
			"SEPARATOR",
			LOOTDESTROYER_CONFIG_HEADER,
			LOOTDESTROYER_CONFIG_HEADER_INFO
		);
		Cosmos_RegisterConfiguration(
			"COS_LOOTDESTROYER_ENABLED",
			"CHECKBOX",
			LOOTDESTROYER_ENABLED,
			LOOTDESTROYER_ENABLED_INFO,
			LootDestroyer_Toggle_Enabled,
			LootDestroyer_Enabled
		);
		LootDestroyer_CosmosRegistered = 1;
	end
end


function LootDestroyer_Register()
	if ( Cosmos_RegisterConfiguration ) then
		LootDestroyer_Register_Cosmos();
	else
		SlashCmdList["LOOTDESTROYERSLASHENABLE"] = LootDestroyer_Enable_ChatCommandHandler;
		SLASH_LOOTDESTROYERSLASHENABLE1 = "/lootdestroyerenable";
		SLASH_LOOTDESTROYERSLASHENABLE2 = "/ldenable";
		SLASH_LOOTDESTROYERSLASHENABLE3 = "/lootdestroyerdisable";
		SLASH_LOOTDESTROYERSLASHENABLE4 = "/lddisable";
		SlashCmdList["LOOTDESTROYERSLASHCLEAR"] = LootDestroyer_Clear_ChatCommandHandler;
		SLASH_LOOTDESTROYERSLASHCLEAR1 = "/lootdestroyerclear";
		SLASH_LOOTDESTROYERSLASHCLEAR2 = "/ldclear";
		SlashCmdList["LOOTDESTROYERSLASHSHOW"] = LootDestroyer_List_ChatCommandHandler;
		SLASH_LOOTDESTROYERSLASHSHOW1 = "/lootdestroyershow";
		SLASH_LOOTDESTROYERSLASHSHOW2 = "/ldshow";
		SLASH_LOOTDESTROYERSLASHSHOW3 = "/lootdestroyerlist";
		SLASH_LOOTDESTROYERSLASHSHOW4 = "/ldlist";
		SlashCmdList["LOOTDESTROYERSLASHTOGGLE"] = LootDestroyer_Toggle_ChatCommandHandler;
		SLASH_LOOTDESTROYERSLASHSHOW1 = "/lootdestroyertoggle";
		SLASH_LOOTDESTROYERSLASHSHOW2 = "/ldtoggle";
		SLASH_LOOTDESTROYERSLASHSHOW3 = "/lootdestroyeradd";
		SLASH_LOOTDESTROYERSLASHSHOW4 = "/ldadd";
		SLASH_LOOTDESTROYERSLASHSHOW5 = "/lootdestroyerremove";
		SLASH_LOOTDESTROYERSLASHSHOW6 = "/ldremove";
		this:RegisterEvent("VARIABLES_LOADED");
	end
	if ( Cosmos_RegisterChatCommand ) then
		local LootDestroyerEnableCommands = {"/lootdestroyerenable","/ldenable","/lootdestroyerdisable","/lddisable"};
		local LootDestroyerClearCommands = {"/lootdestroyerclear","/ldclear"};
		local LootDestroyerListCommands = {"/lootdestroyershow","/ldshow","/lootdestroyerlist","/ldlist"};
		local LootDestroyerToggleCommands = {"/lootdestroyertoggle","/ldtoggle","/lootdestroyeradd","/ldadd","/lootdestroyerremove","/ldremove"};
		Cosmos_RegisterChatCommand (
			"LOOTDESTROYER_ENABLE_COMMANDS", -- Some Unique Group ID
			LootDestroyerEnableCommands, -- The Commands
			LootDestroyer_Enable_ChatCommandHandler,
			LOOTDESTROYER_CHAT_COMMAND_ENABLE_INFO -- Description String
		);
		Cosmos_RegisterChatCommand (
			"LOOTDESTROYER_CLEAR_COMMANDS", -- Some Unique Group ID
			LootDestroyerClearCommands, -- The Commands
			LootDestroyer_Clear_ChatCommandHandler,
			LOOTDESTROYER_CHAT_COMMAND_CLEAR_INFO -- Description String
		);
		Cosmos_RegisterChatCommand (
			"LOOTDESTROYER_LIST_COMMANDS", -- Some Unique Group ID
			LootDestroyerListCommands, -- The Commands
			LootDestroyer_List_ChatCommandHandler,
			LOOTDESTROYER_CHAT_COMMAND_LIST_INFO -- Description String
		);
		Cosmos_RegisterChatCommand (
			"LOOTDESTROYER_TOGGLE_COMMANDS", -- Some Unique Group ID
			LootDestroyerToggleCommands, -- The Commands
			LootDestroyer_Toggle_ChatCommandHandler,
			LOOTDESTROYER_CHAT_COMMAND_TOGGLE_INFO -- Description String
		);
	end

	this:RegisterEvent("BAG_UPDATE");
end

function LootDestroyer_Enable_ChatCommandHandler(msg)
	msg = string.lower(msg);
	
	-- Toggle appropriately
	if ( (string.find(msg, 'on')) or ((string.find(msg, '1')) and (not string.find(msg, '-1')) ) ) then
		LootDestroyer_Toggle_Enabled(1);
	else
		if ( (string.find(msg, 'off')) or (string.find(msg, '0')) ) then
			LootDestroyer_Toggle_Enabled(0);
		else
			LootDestroyer_Toggle_Enabled(-1);
		end
	end
end

function LootDestroyer_Clear_ChatCommandHandler(msg)
	LootDestroyer_ClearUnwantedItems();
end

function LootDestroyer_List_ChatCommandHandler(msg)
	LootDestroyer_ShowUnwantedItems();
end

function LootDestroyer_Toggle_ChatCommandHandler(msg)
	LootDestroyer_ToggleUnwantedItem(msg);
end

function LootDestroyer_ClearUnwantedItems()
	LootDestroyer_UnwantedItems = {};
	LootDestroyer_Print(LOOTDESTROYER_CHAT_LIST_CLEARED);
end

function LootDestroyer_Setup_Hooks(toggle)
	if ( toggle == 1 ) then
		if ( ( LootFrameItem_OnClick ~= LootDestroyer_LootFrameItem_OnClick ) and (LootDestroyer_Saved_LootFrameItem_OnClick == nil) ) then
			LootDestroyer_Saved_LootFrameItem_OnClick = LootFrameItem_OnClick;
			LootFrameItem_OnClick = LootDestroyer_LootFrameItem_OnClick;
		end
		if ( ( ContainerFrameItemButton_OnClick ~= LootDestroyer_ContainerFrameItemButton_OnClick ) and (LootDestroyer_Saved_ContainerFrameItemButton_OnClick == nil) ) then
			LootDestroyer_Saved_ContainerFrameItemButton_OnClick = ContainerFrameItemButton_OnClick;
			ContainerFrameItemButton_OnClick = LootDestroyer_ContainerFrameItemButton_OnClick;
		end
		if ( ( LootDestroyer_OverloadLootUpdate_Enabled == 1 ) and ( LootFrame_Update ~= LootDestroyer_LootFrame_Update ) and (LootDestroyer_Saved_LootFrame_Update == nil) ) then
			LootDestroyer_Saved_LootFrame_Update = LootFrame_Update;
			LootFrame_Update = LootDestroyer_LootFrame_Update;
		end
	else
		if ( LootFrameItem_OnClick == LootDestroyer_LootFrameItem_OnClick) then
			LootFrameItem_OnClick = LootDestroyer_Saved_LootFrameItem_OnClick;
			LootDestroyer_Saved_LootFrameItem_OnClick = nil;
		end
		if ( ContainerFrameItemButton_OnClick == LootDestroyer_ContainerFrameItemButton_OnClick) then
			ContainerFrameItemButton_OnClick = LootDestroyer_Saved_ContainerFrameItemButton_OnClick;
			LootDestroyer_Saved_ContainerFrameItemButton_OnClick = nil;
		end
		if ( LootFrame_Update == LootDestroyer_LootFrame_Update) then
			LootFrame_Update = LootDestroyer_Saved_LootFrame_Update;
			LootDestroyer_Saved_LootFrame_Update = nil;
		end
	end
end


function LootDestroyer_OnEvent(event)
	if ( event == "VARIABLES_LOADED" ) then
		if(LootDestroyer_CosmosRegistered == 0) then
			local value = getglobal("COS_LOOTDESTROYER_ENABLED_X");
			if (value == nil ) then
				-- defaults to off
				value = 0;
			end
			LootDestroyer_Toggle_Enabled(value);
		end
	end
	if ( event == "BAG_UPDATE" ) then
		if ( LootDestroyer_Enabled == 1 ) then
			LootDestroyer_DestroyNewUnwantedItems();
		end
	end
end

function LootDestroyer_ShowUnwantedItems()
	LootDestroyer_Print(LOOTDESTROYER_CHAT_UNWANTED_ITEMS_LIST);
	for k,v in LootDestroyer_UnwantedItems do
		LootDestroyer_Print(v);
	end
end

function LootDestroyer_ToggleUnwantedItem(itemName)
	if (itemName == nil) then
		LootDestroyer_Print(LOOTDESTROYER_CHAT_ERROR_TOGGLE_NIL);
		return;
	end
	for k,v in LootDestroyer_UnwantedItems do
		if ( v == itemName) then
			table.remove(LootDestroyer_UnwantedItems, k);
			LootDestroyer_Print(format(LOOTDESTROYER_CHAT_ITEM_REMOVED, v));
			return;
		end
	end
	table.insert(LootDestroyer_UnwantedItems, itemName);
	LootDestroyer_Print(format(LOOTDESTROYER_CHAT_ITEM_ADDED, itemName));
	-- basically, if we are messing with the LootFrame_Update, we should force an update 
	-- when we have toggled the item unwanted list, as that may have changed what the user should see.
	if ( ( LootFrameItem_Update == LootDestroyer_LootFrameItem_Update ) and (LootFrame) and (LootFrame:IsVisible() ) ) then
		LootFrame_Update();
	end
end

function LootDestroyer_Toggle_Enabled(toggle)
	local oldvalue = LootDestroyer_Enabled;
	local newvalue = toggle;
	if ( ( toggle ~= 1 ) and ( toggle ~= 0 ) ) then
		if (oldvalue == 1) then
			newvalue = 0;
		elseif ( oldvalue == 0 ) then
			newvalue = 1;
		else
			newvalue = 0;
		end
	end
	LootDestroyer_Enabled = newvalue;
	setglobal("COS_LOOTDESTROYER_ENABLED_X", newvalue);
	LootDestroyer_Setup_Hooks(newvalue);
	if ( newvalue ~= oldvalue ) then
		if ( newvalue == 1 ) then
			LootDestroyer_Print(LOOTDESTROYER_CHAT_ENABLED);
		else
			LootDestroyer_Print(LOOTDESTROYER_CHAT_DISABLED);
		end
	end
	if ( newvalue == 0) then
		LootDestroyer_RecentUnwantedItems = {};
	end
	LootDestroyer_Register_Cosmos();
	--if ( LootDestroyer_CosmosRegistered == 0 ) then 
		RegisterForSave("COS_LOOTDESTROYER_ENABLED_X");	
	--end
end

function LootDestroyer_IsUnwantedItem(itemName)
	for k,v in LootDestroyer_UnwantedItems do
		if ( v == itemName) then
			return 1;
		end
	end
	return 0;
end

function LootDestroyer_DestroyItem(itemName)
	if(CursorHasItem()) then
		LootDestroyer_Print(LOOTDESTROYER_CHAT_CURSORHASITEM);
		return false;
	end
	local bag = -1;
	local slot = -1;
	bag, slot = LootDestroyer_FindItemByName(itemName);
	if ( ( bag > -1 ) and ( slot > -1) ) then
 		local texture, itemCount, locked, quality, readable = GetContainerItemInfo(bag, slot);
		if (itemCount > 1) then
			SplitContainerItem(bag, slot, 1);
		else
			PickupContainerItem(bag, slot);
		end
		DeleteCursorItem();
		if (LootDestroyer_DebugPrint_Enabled == true) then
			LootDestroyer_Print(format(LOOTDESTROYER_CHAT_ITEM_HAS_BEEN_REMOVED, itemName));
		end
	end
end

function LootDestroyer_AddNewUnwantedItem(itemName, quantity)
	if (not quantity ) then
		quantity = 1;
	end
	for i = 1, quantity do
		table.insert(LootDestroyer_RecentUnwantedItems, itemName);
	end
	if (LootDestroyer_DebugPrint_Enabled == true) then
		LootDestroyer_Print(format(LOOTDESTROYER_CHAT_ITEM_WILL_BE_REMOVED, itemName));
	end
end

function LootDestroyer_LootFrame_Update()
	if ( LootDestroyer_Saved_LootFrame_Update ) then
		LootDestroyer_Saved_LootFrame_Update();
	end
	for index = 1, LOOTFRAME_NUMBUTTONS, 1 do
		local button = getglobal("LootButton"..index);
		if ( button:IsVisible() ) then
			local slot = LootDestroyer_LootFrameItem_Slot(index);
			local texture;
			local item;
			local quantity;
			texture, item, quantity = GetLootSlotInfo(slot);
			--local itemName = getglobal("LootButton"..index.."Text"):GetText();
			local itemName = item;
			local countString = getglobal("LootButton"..index.."Count");
			if ( LootDestroyer_IsUnwantedItem(itemName) == 1 ) then
				if ( LootDestroyer_Display_Unwanted_Use_Quantity_Enabled == 1 ) then
					countString:SetText("X");
					countString:Show();
				end
				if ( LootDestroyer_Display_Unwanted_Use_Texture_Enabled == 1 ) then
					getglobal("LootButton"..index.."IconTexture"):SetTexture(LOOTDESTROYER_UNWANTED_ITEM_TEXTURE);
					countString:Hide();
				end
			else
				local count = countString:GetText();
				if ( count == "X" ) then
					countString:SetText(quantity);
					if ( quantity <= 1 ) then
						countString:Hide();
					else
						countString:Show();
					end
				end
				-- it is actually unnecessary to restore texture as that is already done by the old method
				--getglobal("LootButton"..index.."IconTexture"):SetTexture(texture);
			end
		end
	end
end

function LootDestroyer_DestroyNewUnwantedItems()
	if ( table.getn(LootDestroyer_RecentUnwantedItems) > 0 ) then
		-- the reason for moving the list to a local variable is to handle concurrent BAG_UPDATE events
		-- it is probably not necessary, but it is good to handle the situation anyhow
		local tableWithItemsToDelete = LootDestroyer_RecentUnwantedItems;
		LootDestroyer_RecentUnwantedItems = {};
		for k, v in tableWithItemsToDelete do
			LootDestroyer_DestroyItem(v);
		end
	end
end

function LootDestroyer_ContainerFrameItemButton_OnClick(button, ignoreShift)
	if ( LootDestroyer_Enabled == 1) then
		if ( ( button == "RightButton" ) and ( IsControlKeyDown() ) ) then
			local itemName = LootDestroyer_GetContainerItemName(this:GetParent():GetID(), this:GetID());
			if ( itemName ~= nil) then
				LootDestroyer_ToggleUnwantedItem(itemName);
			end
			return;
		end
	end
	if ( LootDestroyer_Saved_ContainerFrameItemButton_OnClick ) then
		LootDestroyer_Saved_ContainerFrameItemButton_OnClick(button, ignoreShift);
	end
end


function LootDestroyer_GetContainerItemName(bag, slot)
	if ( LootDestroyer_TooltipsCanBeUsed() ) then
		local strings = LootDestroyerTooltip_GetItemInfoStrings(bag, slot);
		if ( table.getn(strings) > 0 ) then
			if ( strings[1].right ~= nil ) then
				return strings[1].right;
			elseif ( strings[1].left ~= nil ) then
				return strings[1].left;
			end
		end
	else
		LootDestroyer_Print(LOOTDESTROYER_CHAT_TOOLTIP_IN_USE);
	end
	return nil;
end

function LootDestroyer_LootFrameItem_Slot(index)
	local numLootItems = LootFrame.numLootItems;
	--Logic to determine how many items to show per page
	local numLootToShow = LOOTFRAME_NUMBUTTONS;
	if ( numLootItems > LOOTFRAME_NUMBUTTONS ) then
		numLootToShow = numLootToShow - 1;
	end
	local slot = (numLootToShow * (LootFrame.page - 1)) + index;
	return slot;
end

function LootDestroyer_LootFrameItem_DoStuff(index, rightButton)
	local slot = LootDestroyer_LootFrameItem_Slot(index);
	local texture;
	local item;
	local quantity;
	texture, item, quantity = GetLootSlotInfo(slot);
	--local itemName = getglobal("LootButton"..index.."Text"):GetText();
	local itemName = item;
	if ( rightButton == 1) then
		if ( ( IsShiftKeyDown() ) or ( IsControlKeyDown() ) ) then
			LootDestroyer_ToggleUnwantedItem(itemName);
		end
	end
	if ( LootDestroyer_IsUnwantedItem(itemName) == 1 ) then
		LootDestroyer_AddNewUnwantedItem(itemName, quantity);
	end
end

function LootDestroyer_LootFrameItem_OnClick(button)
	if ( LootDestroyer_Enabled == 1) then
		if ( button == "LeftButton" ) then
			if ( not IsShiftKeyDown() ) then
				local index = this:GetID();
				LootDestroyer_LootFrameItem_DoStuff(index, 0);
			end
		end
		if ( button == "RightButton" ) then
			local index = this:GetID();
			LootDestroyer_LootFrameItem_DoStuff(index, 1);
		end
	end
	if ( LootDestroyer_Saved_LootFrameItem_OnClick ) then
		LootDestroyer_Saved_LootFrameItem_OnClick(button);
	end
end
	
	
function LootDestroyer_Print(msg,r,g,b,frame,id,unknown4th)
	if(unknown4th) then
		local temp = id;
		id = unknown4th;
		unknown4th = id;
	end
				
	if (not r) then r = 1.0; end
	if (not g) then g = 1.0; end
	if (not b) then b = 1.0; end
	if ( frame ) then 
		frame:AddMessage(msg,r,g,b,id,unknown4th);
	else
		if ( DEFAULT_CHAT_FRAME ) then 
			DEFAULT_CHAT_FRAME:AddMessage(msg, r, g, b,id,unknown4th);
		end
	end
end

-- Item helper methods
function LootDestroyer_GetNumberOfBags()
	return LOOTDESTROYER_MAX_NUMBER_OF_BAGS;
end

function LootDestroyer_GetNumberOfBagSlots(bag)
	return GetContainerNumSlots(bag);
end


-- This function finds the specified item, return its bag, slot position
function LootDestroyer_FindItemByName(itemName)
	return LootDestroyer_FindItemByName_LastFirst(itemName);
end

-- This function starts at the end of the bags and goes backwards until it finds the item in question
function LootDestroyer_FindItemByName_LastFirst(itemName)
	local bag = 0;
	local slot = 0;
	for bag = LootDestroyer_GetNumberOfBags(), 0, -1 do
		for slot = LootDestroyer_GetNumberOfBagSlots(bag), 1, -1 do
			if ( LootDestroyer_ContainerItemHasName(itemName, bag, slot) == 1) then
				return bag, slot;
			end
		end
	end
	return -1, -1;
end


function LootDestroyer_ContainerItemHasName(itemName, bag, slot)
	local strings = LootDestroyerTooltip_GetItemInfoStrings(bag, slot);
	if ( ( strings == nil ) or ( table.getn(strings) <= 0 ) ) then
		return 0;
	end
	if ( ( strings[1] == itemName ) or ( strings[1].left == itemName ) or ( strings[1].right == itemName ) ) then
		return 1;
	else
		return 0;
	end
end

-- tooltip helper function
LOOTDESTROYER_TOOLTIPS_UNSAFE_FRAMES = { 
   "TaxiFrame", "MerchantFrame", "TradeSkillFrame", "SuggestFrame", "WhoFrame", "AuctionFrame", "MailFrame" 
   }; 

-- use this to add unsafe frames 
function LootDestroyer_TooltipsCanNotBeUsedWithFrame(frame) 
   table.insert(LOOTDESTROYER_TOOLTIPS_UNSAFE_FRAMES, frame); 
end 


-- will return 1 if it is "safe" to use tooltips, otherwise 0 
function LootDestroyer_TooltipsCanBeUsed() 
   local frame = nil; 
   for k, v in LOOTDESTROYER_TOOLTIPS_UNSAFE_FRAMES do 
      frame = getglobal(v); 
      if ( ( frame ) and ( frame:IsVisible() ) ) then 
         return 0; 
      end 
   end 
   return 1; 
end


-- Helper methods from Cosmos
-- All credit should go to the Cosmos team for this one!

-- Gets all lines out of a tooltip.
function LootDestroyerTooltip_ScanTooltip(TooltipNameBase)
	if ( TooltipNameBase == nil ) then 
		TooltipNameBase = "LootDestroyerTooltip";
	end
	
	local strings = {};
	for idx = 1, 10 do
		local textLeft = nil;
		local textRight = nil;
		ttext = getglobal(TooltipNameBase.."TextLeft"..idx);
		if(ttext and ttext:IsVisible() and ttext:GetText() ~= nil)
		then
			textLeft = ttext:GetText();
		end
		ttext = getglobal(TooltipNameBase.."TextRight"..idx);
		if(ttext and ttext:IsVisible() and ttext:GetText() ~= nil)
		then
			textRight = ttext:GetText();
		end
		if (textLeft or textRight)
		then
			strings[idx] = {};
			strings[idx].left = textLeft;
			strings[idx].right = textRight;
		end
	end
	
	return strings;
end

-- Obtains all information about a bag/slot and returns it as an array 
function LootDestroyerTooltip_GetItemInfoStrings(bag,slot, TooltipNameBase)
	if ( TooltipNameBase == nil ) then 
		TooltipNameBase = "LootDestroyerTooltip";
	end

	--ClearTooltip(TooltipNameBase);
	local tooltip = getglobal(TooltipNameBase);
	
	for i=1, tooltip:NumLines(), 1 do
		getglobal(TooltipNameBase.."TextLeft"..i):SetText("");
		getglobal(TooltipNameBase.."TextRight"..i):SetText("");
	end

	-- Open tooltip & read contents

	tooltip:SetText("");
	tooltip:SetBagItem( bag, slot );
	local strings = LootDestroyerTooltip_ScanTooltip(TooltipNameBase);

	-- Done our duty, send report
	return strings;
end


